@@ -1231,6 +1231,7 @@
         UI_SET_SHORTCUT: "ui-set-shortcut",
         UI_TOGGLE_ACTIVE_TAB: "ui-toggle-active-tab",
         UI_MARK_NEWS_AS_READ: "ui-mark-news-as-read",
+        UI_MARK_NEWS_AS_DISPLAYED: "ui-mark-news-as-displayed",
         UI_LOAD_CONFIG: "ui-load-config",
         UI_APPLY_DEV_DYNAMIC_THEME_FIXES: "ui-apply-dev-dynamic-theme-fixes",
         UI_RESET_DEV_DYNAMIC_THEME_FIXES: "ui-reset-dev-dynamic-theme-fixes",
@@ -2638,6 +2639,12 @@
                 data: ids
             });
         }
+        markNewsAsDisplayed(ids) {
+            chrome.runtime.sendMessage({
+                type: MessageType.UI_MARK_NEWS_AS_DISPLAYED,
+                data: ids
+            });
+        }
         loadConfig(options) {
             chrome.runtime.sendMessage({
                 type: MessageType.UI_LOAD_CONFIG,
